@@ -91,6 +91,7 @@ InfiniteScrollViewer::InfiniteScrollViewer(QWidget* mainWindow,
 
 	mCurrentSection = startingSection;
 	mCurrentParagraph = startingParagraph;
+	mHasDoneInitialFill = false;
 }
 
 InfiniteScrollViewer::~InfiniteScrollViewer()
@@ -135,14 +136,15 @@ void InfiniteScrollViewer::fillInitial(int section, int startingParagraph)
 	insertSectionStart(cursor, section);
 	int lastParagraph = startingParagraph + 10;
 	if (lastParagraph >= mTextSource->getNumParagraphs(section))
-		lastParagraph = mTextSource->getNumParagraphs(section);
-	for (int i = 0; i < lastParagraph; i++)
+		lastParagraph = mTextSource->getNumParagraphs(section) - 1;
+	for (int i = 0; i <= lastParagraph; i++)
 		insertParagraph(cursor, section, i);
 
 	mFirstSection = section;
 	mFirstParagraph = 0;
 	mLastSection = section;
 	mLastParagraph = lastParagraph;
+	mHasDoneInitialFill = true;
 
 	fillBottomText();
 
@@ -226,6 +228,9 @@ bool InfiniteScrollViewer::filledToEnd()
 
 void InfiniteScrollViewer::initialScroll()
 {
+	if (!mHasDoneInitialFill)
+		return;
+	fillBottomTextIfNecessary();
 	scrollTo(mCurrentSection, mCurrentParagraph);
 }
 
